@@ -37,19 +37,10 @@
 #'
 #' @return The input dataset with `ASTDY` column added
 #'
-#' @keywords derivation bds occds timing
+#' @keywords deprecated
 #'
 #' @export
 #'
 derive_var_astdy <- function(dataset, reference_date = TRTSDT, date = ASTDT) {
-  reference_date <- assert_symbol(enquo(reference_date))
-  date <- assert_symbol(enquo(date))
-  assert_data_frame(dataset, vars(!!reference_date, !!date))
-  deprecate_warn("0.7.0", "derive_var_astdy()", "derive_vars_dy()")
-
-  derive_vars_dy(
-    dataset,
-    reference_date = !!reference_date,
-    source_vars = vars(ASTDY = !!date)
-  )
+  deprecate_stop("0.7.0", "derive_var_astdy()", "derive_vars_dy()")
 }
